
# Slot: activities

All of the activities that are part of the model

URI: [gocam:model__activities](https://w3id.org/gocam/model__activities)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Activity](Activity.md)

## Parents


## Children


## Used by

 * [Model](Model.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | this slot is conditionally required. It is optional for models in development state (because a curator may need to instantiate a Model before populating it with activities), but is required for production models. See the associated rule. |
